==> birdtray_1.8.1+ds.orig.tar.xz: birdtray-1.8.1/src/translations/installer_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_BR">
<context>
    <name>WindowsInstaller</name>
    <message>
        <source>__LANGUAGE_NAME__</source>
        <translatorcomment>This must be the name of one of the NSIS translation files at https://sourceforge.net/p/nsis/code/HEAD/tree/NSIS/trunk/Contrib/Language%20files/ without the file extension.</translatorcomment>
        <translation>PortugueseBR</translation>
    </message>
    <message>
        <source>BirdtraySectionDescription</source>
        <translation>Notificação de novos e-mails do Thunderbird direto da Área de Notificação.</translation>
    </message>
    <message>
        <source>WinIntegrationSectionName</source>
        <translation>Integração com o Windows</translation>
    </message>
    <message>
        <source>WinIntegrationGroupDescription</source>
        <translation>Selecione como integrar o programa no Windows.</translation>
    </message>
    <message>
        <source>AutoRunSectionName</source>
        <translation>Execução Automática</translation>
    </message>
    <message>
        <source>AutoRunDescription</source>
        <translation>Automaticamente inicia o ${PRODUCT_NAME} após fazer login.</translation>
    </message>
    <message>
        <source>AutoCheckUpdateSectionName</source>
        <translation>Verificação Automática de Atualizações</translation>
    </message>
    <message>
        <source>AutoCheckUpdateDescription</source>
        <translation>Automaticamente busca por atualizações do ${PRODUCT_NAME} ao iniciar.</translation>
    </message>
    <message>
        <source>ProgramGroupSectionName</source>
        <translation>Entrada do Grupo de Programas</translation>
    </message>
    <message>
        <source>ProgramGroupDescription</source>
        <translation>Cria o grupo do programa ${PRODUCT_NAME} em Menu Iniciar &gt; Programas.</translation>
    </message>
    <message>
        <source>DesktopEntrySectionName</source>
        <translation>Ícone na Área de Trabalho</translation>
    </message>
    <message>
        <source>DesktopEntryDescription</source>
        <translation>Cria um ícone do ${PRODUCT_NAME} na Área de Trabalho.</translation>
    </message>
    <message>
        <source>StartMenuSectionName</source>
        <translation>Entrada no Menu Iniciar</translation>
    </message>
    <message>
        <source>StartMenuDescription</source>
        <translation>Cria um ícone do ${PRODUCT_NAME} no Menu Iniciar.</translation>
    </message>
    <message>
        <source>TranslationsSectionName</source>
        <translation>Traduções</translation>
    </message>
    <message>
        <source>TranslationsDescription</source>
        <translation>Selecione as traduções para o ${PRODUCT_NAME}. O ${PRODUCT_NAME} irá escolher uma tradução baseada no idioma do sistema.</translation>
    </message>
    <message>
        <source>UserSettingsSectionName</source>
        <translation>Configurações do Usuário do ${PRODUCT_NAME}</translation>
    </message>
    <message>
        <source>UserSettingsDescription</source>
        <translation>Suas definições e configurações feitas dentro do ${PRODUCT_NAME}.</translation>
    </message>
    <message>
        <source>LicenseStartMenuLinkName</source>
        <translation>Contrato de Licença</translation>
    </message>
    <message>
        <source>FinishPageRunBirdtray</source>
        <translation>Iniciar o ${PRODUCT_NAME}</translation>
    </message>
    <message>
        <source>UninstallerConfirmation</source>
        <translation>Clique em Desinstalar para iniciar o processo.</translation>
    </message>
    <message>
        <source>UninstallPreviousVersion</source>
        <translation>Desinstalando versão anterior do ${PRODUCT_NAME}</translation>
    </message>
    <message>
        <source>UninstallPreviousVersionError</source>
        <translation>Falha ao desinstalar a versão antiga do ${PRODUCT_NAME}! Continuar irá excluir TUDO em $3.</translation>
    </message>
    <message>
        <source>UninstallExecutionError</source>
        <translation>Erro ao executar desinstalador.</translation>
    </message>
    <message>
        <source>StopBirdtray</source>
        <translation>O ${PRODUCT_NAME} está em execução. Pressione OK para encerrar o ${PRODUCT_NAME} e prosseguir com a instalação.</translation>
    </message>
    <message>
        <source>StoppingBirdtray</source>
        <translation>Encerrando processo ${EXE_NAME}</translation>
    </message>
    <message>
        <source>StopBirdtrayError</source>
        <translation>Falha ao encerrar o ${PRODUCT_NAME}. Por favor, tente novamente ou feche o ${PRODUCT_NAME} manualmente para continuar com a instalação.</translation>
    </message>
    <message>
        <source>StopBirdtrayUninstall</source>
        <translation>O ${PRODUCT_NAME} está em execução. Pressione OK para encerrar o ${PRODUCT_NAME} e continuar com a desinstalação.</translation>
    </message>
    <message>
        <source>StopBirdtrayUninstallError</source>
        <translation>Falha ao fechar o ${PRODUCT_NAME}. Por favor, tente novamente ou feche o ${PRODUCT_NAME} manualmente para continuar com a desinstalação.</translation>
    </message>
    <message>
        <source>SetupAlreadyRunning</source>
        <translation>A instalação do ${PRODUCT_NAME} já está em execução.$\r$\nPor favor, feche todas as instâncias e clique em Repetir para continuar, ou Cancelar para sair.</translation>
    </message>
    <message>
        <source>UninstallAlreadyRunning</source>
        <translation>A desinstalação do ${PRODUCT_NAME} já está em execução.$\r$\nPor favor, feche todas as instâncias e clique em Repetir para continuar, ou Cancelar para sair.</translation>
    </message>
    <message>
        <source>BadInstallPath</source>
        <translation>O caminho de instalação não pode conter os seguintes caracteres:$\r$\n${BAD_PATH_CHARS}.</translation>
    </message>
    <message>
        <source>InstallPathContainsPreviousVersion</source>
        <translation>O caminho de instalação contém uma versão prévia do ${PRODUCT_NAME} instalada, que será substituída.</translation>
    </message>
    <message>
        <source>InstallPathNotEmpty</source>
        <translation>O caminho de instalação não está vazio, mas não parece que ele contém uma instalação prévia do ${PRODUCT_NAME}. O conteúdo será sobrescrito.</translation>
    </message>
    <message>
        <source>CurrentUserOnly</source>
        <translation>$0 (somente usuário atual)</translation>
    </message>
    <message>
        <source>InstallFailed</source>
        <translation>O ${PRODUCT_NAME} ${VERSION} não pôde ser totalmente instalado.$\r$\n\Por favor, reinicie o Windows e execute o programa de instalação novamente.</translation>
    </message>
    <message>
        <source>InstallFailedCauseUninstallerFailed</source>
        <translation>O ${PRODUCT_NAME} não pôde ser totalmente instalado.$\r$\n\Por favor, reinicie o Windows e execute o programa de instalação novamente.</translation>
    </message>
    <message>
        <source>UninstallFailed</source>
        <translation>O ${PRODUCT_NAME} ${VERSION} não pôde ser totalmente desinstalado.$\r$\n\Por favor, reinicie o Windows e execute o programa de desinstalação novamente.</translation>
    </message>
    <message>
        <source>FileDeleteErrorDialog</source>
        <translation>Erro ao excluir arquivo:$\r$\n$\r$\n$0$\r$\n$\r$\nClique em Repetir para tentar novamente, ou$\r$\nCancelar para parar a instalação.</translation>
    </message>
    <message>
        <source>FileDeleteError</source>
        <translation>Erro ao excluir arquivo $0</translation>
    </message>
    <message>
        <source>Install64On32BitWarning</source>
        <translation>Você está prestes a instalar a versão de 32 bits do ${PRODUCT_NAME} no seu Windows de 64 bits. Há uma versão de 64 bits do ${PRODUCT_NAME} disponível para download.</translation>
    </message>
    <message>
        <source>Install32On64BitError</source>
        <translation>Este instalador contém a versão de 64 bits do ${PRODUCT_NAME}. Seu computador está executando uma versão de 32 bits do Windows, que não pode executar programas de 64 bits. Por favor, baixe o instalador de 32 bits do ${PRODUCT_NAME}.</translation>
    </message>
    <message>
        <source>UnsupportedWindowsVersionError</source>
        <translation>Este programa necessita pelo menos do Windows ${MIN_WINDOWS_VER}.</translation>
    </message>
    <message>
        <source>UninstallerAborted</source>
        <translation>A desinstalação do ${PRODUCT_NAME} foi cancelada. Por favor, tente novamente mais tarde.</translation>
    </message>
    <message>
        <source>SettingsLink</source>
        <translation>Configurações do ${PRODUCT_NAME}</translation>
    </message>
    <message>
        <source>UninstallRestartAsUserQuestion</source>
        <translation>O desinstalador foi iniciado com privilégios de administrador, mas parece que não há instalação do {PRODUCT_NAME} para o administrador. Deseja reiniciar o desinstalador sem privilégios de administrador?</translation>
    </message>
    <message>
        <source>OpenUrl</source>
        <translation>Abrindo $0 no navegador padrão...</translation>
    </message>
    <message>
        <source>MissingVcRuntime</source>
        <translation>Não foi possível encontrar o Visual C++ Runtime ${ARCH}.</translation>
    </message>
    <message>
        <source>MissingVcRuntime_Dialog</source>
        <translation>O seguinte componente necessário não foi encontrado neste computador:$\r$\nVisual C++ Runtime ${ARCH}$\r$\nDeseja baixar o instalador para o componente?</translation>
    </message>
    <message>
        <source>MissingVcRuntime_Retry</source>
        <translation>Assim que o download for concluído, execute o instalador baixado. Quando o instalador for concluído, pressione OK para verificar o status da instalação novamente.</translation>
    </message>
    <message>
        <source>MissingVcRuntime_Found</source>
        <translation>O componente necessário foi detectado com sucesso no seu computador.</translation>
    </message>
    <message>
        <source>MissingVcRuntime_StillNotFound</source>
        <translation>O componente necessário não foi encontrado no seu computador. Por favor, pesquise por downloads do Visual C++ {ARCH} para o Visual Studio 2015 ou superior.</translation>
    </message>
    <message>
        <source>MissingVcRuntime_UnableToRun</source>
        <translation>O ${PRODUCT_NAME} não será capaz de ser executado.</translation>
    </message>
    <message>
        <source>MissingVcRuntime_UnableToRunDialog</source>
        <translation>O ${PRODUCT_NAME} não será capaz de ser iniciado pois um componente necessário está faltando.</translation>
    </message>
    <message>
        <source>Lang_en</source>
        <translation>Inglês</translation>
    </message>
    <message>
        <source>Lang_de</source>
        <translation>Alemão</translation>
    </message>
    <message>
        <source>Lang_nl</source>
        <translation>Holandês</translation>
    </message>
    <message>
        <source>Lang_it</source>
        <translation>Italiano</translation>
    </message>
    <message>
        <source>Lang_ru</source>
        <translation>Russo</translation>
    </message>
    <message>
        <source>Lang_pt</source>
        <translation>Português</translation>
    </message>
    <message>
        <source>Lang_es</source>
        <translation>Espanhol</translation>
    </message>
</context>
</TS>

==> birdtray_1.9.0+ds.orig.tar.xz: birdtray-1.9.0/src/translations/installer_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_BR">
<context>
    <name>WindowsInstaller</name>
    <message>
        <source>__LANGUAGE_NAME__</source>
        <translatorcomment>This must be the name of one of the NSIS translation files at https://sourceforge.net/p/nsis/code/HEAD/tree/NSIS/trunk/Contrib/Language%20files/ without the file extension.</translatorcomment>
        <translation>PortugueseBR</translation>
    </message>
    <message>
        <source>BirdtraySectionDescription</source>
        <translation>Notificação de novos e-mails do Thunderbird direto da Área de Notificação.</translation>
    </message>
    <message>
        <source>WinIntegrationSectionName</source>
        <translation>Integração com o Windows</translation>
    </message>
    <message>
        <source>WinIntegrationGroupDescription</source>
        <translation>Selecione como integrar o programa no Windows.</translation>
    </message>
    <message>
        <source>AutoRunSectionName</source>
        <translation>Execução Automática</translation>
    </message>
    <message>
        <source>AutoRunDescription</source>
        <translation>Automaticamente inicia o ${PRODUCT_NAME} após fazer login.</translation>
    </message>
    <message>
        <source>AutoCheckUpdateSectionName</source>
        <translation>Verificação Automática de Atualizações</translation>
    </message>
    <message>
        <source>AutoCheckUpdateDescription</source>
        <translation>Automaticamente busca por atualizações do ${PRODUCT_NAME} ao iniciar.</translation>
    </message>
    <message>
        <source>ProgramGroupSectionName</source>
        <translation>Entrada do Grupo de Programas</translation>
    </message>
    <message>
        <source>ProgramGroupDescription</source>
        <translation>Cria o grupo do programa ${PRODUCT_NAME} em Menu Iniciar &gt; Programas.</translation>
    </message>
    <message>
        <source>DesktopEntrySectionName</source>
        <translation>Ícone na Área de Trabalho</translation>
    </message>
    <message>
        <source>DesktopEntryDescription</source>
        <translation>Cria um ícone do ${PRODUCT_NAME} na Área de Trabalho.</translation>
    </message>
    <message>
        <source>StartMenuSectionName</source>
        <translation>Entrada no Menu Iniciar</translation>
    </message>
    <message>
        <source>StartMenuDescription</source>
        <translation>Cria um ícone do ${PRODUCT_NAME} no Menu Iniciar.</translation>
    </message>
    <message>
        <source>TranslationsSectionName</source>
        <translation>Traduções</translation>
    </message>
    <message>
        <source>TranslationsDescription</source>
        <translation>Selecione as traduções para o ${PRODUCT_NAME}. O ${PRODUCT_NAME} irá escolher uma tradução baseada no idioma do sistema.</translation>
    </message>
    <message>
        <source>UserSettingsSectionName</source>
        <translation>Configurações do Usuário do ${PRODUCT_NAME}</translation>
    </message>
    <message>
        <source>UserSettingsDescription</source>
        <translation>Suas definições e configurações feitas dentro do ${PRODUCT_NAME}.</translation>
    </message>
    <message>
        <source>LicenseStartMenuLinkName</source>
        <translation>Contrato de Licença</translation>
    </message>
    <message>
        <source>FinishPageRunBirdtray</source>
        <translation>Iniciar o ${PRODUCT_NAME}</translation>
    </message>
    <message>
        <source>UninstallerConfirmation</source>
        <translation>Clique em Desinstalar para iniciar o processo.</translation>
    </message>
    <message>
        <source>UninstallPreviousVersion</source>
        <translation>Desinstalando versão anterior do ${PRODUCT_NAME}</translation>
    </message>
    <message>
        <source>UninstallPreviousVersionError</source>
        <translation>Falha ao desinstalar a versão antiga do ${PRODUCT_NAME}! Continuar irá excluir TUDO em $3.</translation>
    </message>
    <message>
        <source>UninstallExecutionError</source>
        <translation>Erro ao executar desinstalador.</translation>
    </message>
    <message>
        <source>StopBirdtray</source>
        <translation>O ${PRODUCT_NAME} está em execução. Pressione OK para encerrar o ${PRODUCT_NAME} e prosseguir com a instalação.</translation>
    </message>
    <message>
        <source>StoppingBirdtray</source>
        <translation>Encerrando processo ${EXE_NAME}</translation>
    </message>
    <message>
        <source>StopBirdtrayError</source>
        <translation>Falha ao encerrar o ${PRODUCT_NAME}. Por favor, tente novamente ou feche o ${PRODUCT_NAME} manualmente para continuar com a instalação.</translation>
    </message>
    <message>
        <source>StopBirdtrayUninstall</source>
        <translation>O ${PRODUCT_NAME} está em execução. Pressione OK para encerrar o ${PRODUCT_NAME} e continuar com a desinstalação.</translation>
    </message>
    <message>
        <source>StopBirdtrayUninstallError</source>
        <translation>Falha ao fechar o ${PRODUCT_NAME}. Por favor, tente novamente ou feche o ${PRODUCT_NAME} manualmente para continuar com a desinstalação.</translation>
    </message>
    <message>
        <source>SetupAlreadyRunning</source>
        <translation>A instalação do ${PRODUCT_NAME} já está em execução.$\r$\nPor favor, feche todas as instâncias e clique em Repetir para continuar, ou Cancelar para sair.</translation>
    </message>
    <message>
        <source>UninstallAlreadyRunning</source>
        <translation>A desinstalação do ${PRODUCT_NAME} já está em execução.$\r$\nPor favor, feche todas as instâncias e clique em Repetir para continuar, ou Cancelar para sair.</translation>
    </message>
    <message>
        <source>BadInstallPath</source>
        <translation>O caminho de instalação não pode conter os seguintes caracteres:$\r$\n${BAD_PATH_CHARS}.</translation>
    </message>
    <message>
        <source>InstallPathContainsPreviousVersion</source>
        <translation>O caminho de instalação contém uma versão prévia do ${PRODUCT_NAME} instalada, que será substituída.</translation>
    </message>
    <message>
        <source>InstallPathNotEmpty</source>
        <translation>O caminho de instalação não está vazio, mas não parece que ele contém uma instalação prévia do ${PRODUCT_NAME}. O conteúdo será sobrescrito.</translation>
    </message>
    <message>
        <source>CurrentUserOnly</source>
        <translation>$0 (somente usuário atual)</translation>
    </message>
    <message>
        <source>InstallFailed</source>
        <translation>O ${PRODUCT_NAME} ${VERSION} não pôde ser totalmente instalado.$\r$\n\Por favor, reinicie o Windows e execute o programa de instalação novamente.</translation>
    </message>
    <message>
        <source>InstallFailedCauseUninstallerFailed</source>
        <translation>O ${PRODUCT_NAME} não pôde ser totalmente instalado.$\r$\n\Por favor, reinicie o Windows e execute o programa de instalação novamente.</translation>
    </message>
    <message>
        <source>UninstallFailed</source>
        <translation>O ${PRODUCT_NAME} ${VERSION} não pôde ser totalmente desinstalado.$\r$\n\Por favor, reinicie o Windows e execute o programa de desinstalação novamente.</translation>
    </message>
    <message>
        <source>FileDeleteErrorDialog</source>
        <translation>Erro ao excluir arquivo:$\r$\n$\r$\n$0$\r$\n$\r$\nClique em Repetir para tentar novamente, ou$\r$\nCancelar para parar a instalação.</translation>
    </message>
    <message>
        <source>FileDeleteError</source>
        <translation>Erro ao excluir arquivo $0</translation>
    </message>
    <message>
        <source>Install64On32BitWarning</source>
        <translation>Você está prestes a instalar a versão de 32 bits do ${PRODUCT_NAME} no seu Windows de 64 bits. Há uma versão de 64 bits do ${PRODUCT_NAME} disponível para download.</translation>
    </message>
    <message>
        <source>Install32On64BitError</source>
        <translation>Este instalador contém a versão de 64 bits do ${PRODUCT_NAME}. Seu computador está executando uma versão de 32 bits do Windows, que não pode executar programas de 64 bits. Por favor, baixe o instalador de 32 bits do ${PRODUCT_NAME}.</translation>
    </message>
    <message>
        <source>UnsupportedWindowsVersionError</source>
        <translation>Este programa necessita pelo menos do Windows ${MIN_WINDOWS_VER}.</translation>
    </message>
    <message>
        <source>UninstallerAborted</source>
        <translation>A desinstalação do ${PRODUCT_NAME} foi cancelada. Por favor, tente novamente mais tarde.</translation>
    </message>
    <message>
        <source>SettingsLink</source>
        <translation>Configurações do ${PRODUCT_NAME}</translation>
    </message>
    <message>
        <source>UninstallRestartAsUserQuestion</source>
        <translation>O desinstalador foi iniciado com privilégios de administrador, mas parece que não há instalação do ${PRODUCT_NAME} para o administrador. Deseja reiniciar o desinstalador sem privilégios de administrador?</translation>
    </message>
    <message>
        <source>OpenUrl</source>
        <translation>Abrindo $0 no navegador padrão...</translation>
    </message>
    <message>
        <source>MissingVcRuntime</source>
        <translation>Não foi possível encontrar o Visual C++ Runtime ${ARCH}.</translation>
    </message>
    <message>
        <source>MissingVcRuntime_Dialog</source>
        <translation>O seguinte componente necessário não foi encontrado neste computador:$\r$\nVisual C++ Runtime ${ARCH}$\r$\nDeseja baixar o instalador para o componente?</translation>
    </message>
    <message>
        <source>MissingVcRuntime_Retry</source>
        <translation>Assim que o download for concluído, execute o instalador baixado. Quando o instalador for concluído, pressione OK para verificar o status da instalação novamente.</translation>
    </message>
    <message>
        <source>MissingVcRuntime_Found</source>
        <translation>O componente necessário foi detectado com sucesso no seu computador.</translation>
    </message>
    <message>
        <source>MissingVcRuntime_StillNotFound</source>
        <translation>O componente necessário não foi encontrado no seu computador. Por favor, pesquise por downloads do Visual C++ ${ARCH} para o Visual Studio 2015 ou superior.</translation>
    </message>
    <message>
        <source>MissingVcRuntime_UnableToRun</source>
        <translation>O ${PRODUCT_NAME} não será capaz de ser executado.</translation>
    </message>
    <message>
        <source>MissingVcRuntime_UnableToRunDialog</source>
        <translation>O ${PRODUCT_NAME} não será capaz de ser iniciado pois um componente necessário está faltando.</translation>
    </message>
    <message>
        <source>Lang_en</source>
        <translation>Inglês</translation>
    </message>
    <message>
        <source>Lang_de</source>
        <translation>Alemão</translation>
    </message>
    <message>
        <source>Lang_nl</source>
        <translation>Holandês</translation>
    </message>
    <message>
        <source>Lang_it</source>
        <translation>Italiano</translation>
    </message>
    <message>
        <source>Lang_ru</source>
        <translation>Russo</translation>
    </message>
    <message>
        <source>Lang_pt</source>
        <translation>Português</translation>
    </message>
    <message>
        <source>Lang_es</source>
        <translation>Espanhol</translation>
    </message>
    <message>
        <source>Lang_sv</source>
        <translation>Sueco</translation>
    </message>
    <message>
        <source>Lang_tr</source>
        <translation>Turco</translation>
    </message>
    <message>
        <source>Lang_pl</source>
        <translation>Polaca</translation>
    </message>
</context>
</TS>
